@@ -1,5 +1,8 @@
 import base64
-from typing import Any, Dict, Mapping, NamedTuple, Optional, Sequence
+from pathlib import Path
+from typing import Any, Dict, Mapping, NamedTuple, Optional, Sequence, Union
+from urllib.parse import urlparse
+
 import requests
 
 
@@ -93,6 +96,39 @@ class Image:
         self.cropping = cropping
         self.controls: Sequence[ImageControl] = controls
 
+    @classmethod
+    def from_image_source(
+        cls,
+        image_source: Union[str, Path, bytes],
+        controls: Optional[Sequence[ImageControl]] = None,
+    ):
+        """
+        Abstraction on top of the existing methods of image initialization.
+        If you are not sure what the exact type of your image, but you know it is either a Path object, URL, a file path,
+        or a bytes array, just use the method and we will figure out which of the methods of image initialization to use
+        """
+        if isinstance(image_source, Path):
+            return cls.from_file(path=str(image_source), controls=controls)
+
+        elif isinstance(image_source, str):
+            try:
+                p = urlparse(image_source)
+                if p.scheme:
+                    return cls.from_url(url=image_source, controls=controls)
+            except Exception as e:
+                # we assume that If the string runs into a Exception it isn't not a valid ulr
+                pass
+
+            return cls.from_file(path=image_source, controls=controls)
+
+        elif isinstance(image_source, bytes):
+            return cls.from_bytes(bytes=image_source, controls=controls)
+
+        else:
+            raise TypeError(
+                f"The image source: {image_source} should be either Path, str or bytes"
+            )
+
     @classmethod
     def from_bytes(
         cls,
